require 'yaml'
require 'date'

module SeedData

  class DataBuilder

    attr_accessor :data_set_dir

    def build(name)

      data = load_data_set_file(name)

      data.each do |itm|
        build_item(itm)
      end

      return true

    end

    #This method should be overwritten by the specific builder implementation.
    def build_item(itm)
      raise 'Not Implemented.'
    end

    def load_data_set_file(name)

      if @data_set_dir.nil?
        raise SeedData::DataSetDirNotSpecifiedException.new
      end

      begin
        return YAML::load_file(File.join(@data_set_dir, "/data_sets/#{name}.yaml"))
      rescue Errno::ENOENT
        raise SeedData::DataSetNotFoundException.new("DataSet: ''#{name}'', could not be found.")
      end

    end

    def fill_entity(entity, params)

      params.keys.each do |key|

        if entity.respond_to?(key.to_sym)
          entity.send("#{key}=", params[key])
        else
          raise SeedData::InvalidDataSetException.new("Invalid Data Set. Unknown entity attribute: #{key}. For entity: #{entity}")
        end

      end

      entity
    end

  end

end